Terminal Velocity
=================


To install Terminal Velocity, run::

    pip install terminal_velocity

Then to launch it just run::

    terminal_velocity

To use a different notes directory, run::

    terminal_velocity path/to/your/notes/dir

To see all the command-line options, run::

    terminal_velocity -h

To quit the app, press ``ctrl-c`` or ``ctrl-x``.

To upgrade Terminal Velocity to the latest version, run::

    pip install --upgrade terminal_velocity

To uninstall it, run::

    pip uninstall terminal_velocity

For screenshots and features, see the
`Terminal Velocity website <http://seanh.github.com/terminal_velocity>`_.

